==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu_basic2.js <==
_me = obj_hmenu_basic2.prototype;
function obj_hmenu_basic2(){};

_me.__constructor = function() {};

_me._contextFill = function(sType, oFolder, sView, bEnabled)
{
	var aMenu;
	this.__oFolder = oFolder;
	
	switch(sType)
	{
		case 'M':
			var folders = (new gw_others).get('DEFAULT_FOLDERS','storage')['VALUES'];
			var sTrashFolder = folders['trash'];
			var sDraftFolder = folders['drafts'];
			var sSentFolder = folders['sent'];
			var sSpamFolder = folders['spam'];
			var sFolderID = oFolder['aid'] + '/' + oFolder['fid'];
			
			aMenu = [];
			if (sFolderID != sDraftFolder && sFolderID != sSentFolder) {
				aMenu.push({"title": 'MAIN_MENU::REPLY_TO_SENDER', 'arg': 'reply_to_sender'});
				aMenu.push({"title": 'MAIN_MENU::REPLY_TO_ALL', 'arg': 'reply_to_all'});
			}
			aMenu.push({"title": 'MAIN_MENU::FORWARD', 'arg': 'forward_from_hmenu'});
            aMenu.push({"title": '-'});
			aMenu.push({"title": 'MAIN_MENU::DELETE', 'arg': 'delete'});
            aMenu.push({"title": '-'});
			aMenu.push({"title": 'MAIN_MENU::PRINT', 'arg': 'print'});
			aMenu.push({"title": 'MAIN_MENU::SEARCH', 'arg': 'search'});
            
			if (sFolderID == sTrashFolder || sFolderID == sSpamFolder)
				aMenu.push({"title": 'MAIN_MENU::EMPTY_FOLDER', 'arg': 'empty_folder'});
			break;

		case 'E':

			aMenu = [
				{"title": 'MAIN_MENU::DAY_VIEW', 'arg': 'day_view'},
				{"title": 'MAIN_MENU::WEEK_VIEW', 'arg':  'week_view'},
				{"title": 'MAIN_MENU::MONTH_VIEW', 'arg': 'month_view'},
				{"title": 'MAIN_MENU::EVENTS_LIST', 'arg': 'list_view'},
                {"title": '-'},
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'}
			];
			
			if (sView == 'list_view')
				aMenu.push({"title": '-'},{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'});
				
			break;

		case 'C':
			aMenu = [
				{"title": 'MAIN_MENU::DIAL', 'arg': 'dial'},{"title": '-'},
				/*{"title": 'MAIN_MENU::CONTACTS_LIST', 'arg': 'phone_list'},
				{"title": 'MAIN_MENU::ADDRESS_CARD', 'arg': 'address_card'},*/

				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'}
			];
			break;

		case 'T':
			aMenu = [
				/*{"title": 'MAIN_MENU::TASKS_LISTS', 'arg': 'tasks_simple'},
				{"title": 'MAIN_MENU::TASKS_DETAILED', 'arg': 'tasks_detailed'},
				{"title": 'MAIN_MENU::ACTIVE_TASKS', 'arg': 'active_tasks'},*/
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;

		case 'J':
			aMenu = [
				/*{"title": 'MAIN_MENU::JOURNAL_DAY_VIEW', 'arg': 'journal_day_view'},
				{"title": 'MAIN_MENU::JOURNAL_WEEK_VIEW', 'arg': 'journal_week_view'},
				{"title": 'MAIN_MENU::JOURNAL_MONTH_VIEW', 'arg': 'journal_month_view'},
				{"title": 'MAIN_MENU::JOURNAL_LIST', 'arg': 'journal_list'},*/
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}

			];
			break;
			
		case 'N':
			aMenu = [
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;
			
		case 'F':
			aMenu = [
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;

		case 'Q':
			aMenu = [
				/*
				{"title": 'MAIN_MENU::WHITE_LISTED', 'arg': 'Whitelist'},
				{"title": 'MAIN_MENU::BLACK_LISTED', 'arg': 'Blacklist'},
				{"title": '-'},
				*/
				{"title": 'MAIN_MENU::DELIVER', 'arg': 'deliver'},
				{"title": 'MAIN_MENU::WHITE_LIST', 'arg': 'whitelist'},
				{"title": 'MAIN_MENU::BLACK_LIST', 'arg': 'blacklist'},
                {"title": '-'},
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
				{"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;

		case 'QL':
			if (oFolder['fid'].indexOf('White') >= 0) {
				aMenu = [
				/*
					{"title": 'MAIN_MENU::QUARANTINE', 'arg': 'Quarantine'},
					{"title": 'MAIN_MENU::BLACK_LISTED', 'arg': 'Blacklist'},
					{"title": '-'},
				*/
					{"title": 'MAIN_MENU::BLACK_LIST', 'arg': 'blacklist'},
                    {"title": '-'},
					{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
	                {"title": '-'},
					{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
				];
			} else {
				aMenu = [
				/*
					{"title": 'MAIN_MENU::QUARANTINE', 'arg': 'Quarantine'},
					{"title": 'MAIN_MENU::WHITE_LISTED', 'arg': 'Whitelist'},
					{"title": '-'},
				*/
					{"title": 'MAIN_MENU::WHITE_LIST', 'arg': 'whitelist'},
                    {"title": '-'},
					{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
	                {"title": '-'},
					{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
				];
			}
			break;
	}

	this._fill(aMenu,'dynamic');
};

_me.__manageEmptyItems = function(id,sAction) {

	switch (sAction) {

		case 'dial':
            if (id[2]) return false;
			this.__showDialDialog();
			return true;

		case 'day_view':
		case 'week_view':
		case 'month_view':
		case 'list_view':
			gui.frm_main._selectView(this.__oFolder, sAction, true);
			return true;
		case 'empty_folder':
			gui._create('frm_confirm', 'frm_confirm', '', '',[WMFolders, '__emptyFolder',
				[this.__oFolder['aid'], this.__oFolder['fid']]],
				'CONFIRMATION::EMPTY_FOLDER_CONFIRMATION', 'CONFIRMATION::EMPTY_FOLDER'
			);
			return true;

		case 'search':
			//HIDE
			if (gui.frm_main.main && gui.frm_main.main.search_item){
                gui.frm_main.main._hidesearch();

				dataSet.remove('datagrid_views',[this.__oFolder['aid'],this.__oFolder['fid'],'search']);
			}
			//SHOW
			else{
				var sFolType = dataSet.get("folders",[this.__oFolder['aid'],this.__oFolder['fid'],'TYPE']);
				gui.frm_main.main._showsearch(sFolType,this.__oFolder['aid']+'/'+this.__oFolder['fid'],true);
				
				dataSet.add('datagrid_views',[this.__oFolder['aid'],this.__oFolder['fid'],'search'],'1');
    	    }
		    return true;
	}
	
	return false;
};

_me.__manageOneItem = function(id, sAction) {
	switch (sAction) {
		case 'reply_to_sender': OldMessage.reply(id, false); return true;
		case 'reply_to_all': OldMessage.reply(id, true); return true;
		case 'forward_from_hmenu': OldMessage.forward(id); return true;
		case 'dial':
			if (count(gui.frm_main.main.list._value()) == 1)
				this.__showDialDialog(id[0], id[1], id[2]);
			else
				this.__showDialDialog();

			return true;
	}
	
	return false;
};

_me.__manageMoreItems = function(ids, sAction) {
	switch (sAction) {
		case 'delete': Item.remove(ids); break;
		case 'deliver': OldMessage.deliver(ids); break;
		case 'whitelist': OldMessage.whitelist(ids); break;
		case 'blacklist': OldMessage.blacklist(ids); break;
	}
};

_me._onclick = function(e, elm, id, sAction)
{
	if (!gui.frm_main.main.list)
		this.__manageEmptyItems([aid, fid],sAction);
	else {

		switch(sAction){
		case 'print':
			if (gui.frm_main.main && gui.frm_main.main.mailview)
                gui.frm_main.main.mailview._print();
			return;
		case 'Whitelist':
		case 'Blacklist':
//		case 'Quarantine':
			gui.frm_main.folders._setActive(this.__oFolder['aid']+'/SPAM_QUEUE/'+sAction);
			gui.frm_main.folders._handleNode({aid:this.__oFolder['aid'],fid:'SPAM_QUEUE/'+sAction,ftype:'QL',candelete:false,canrename:false,disabled:false});
		    return;
		}

		var aSelectedItems = gui.frm_main.main.list._value();
		var aid = this.__oFolder['aid'];
		var fid = this.__oFolder['fid'];

		if (count(aSelectedItems) == 0) {
			this.__manageEmptyItems([aid, fid],sAction);
		}
		else
		if (count(aSelectedItems) == 1) {
			if (!this.__manageEmptyItems([aid, fid, aSelectedItems],sAction))
				if (!this.__manageOneItem([aid, fid, aSelectedItems[0]], sAction))
					this.__manageMoreItems([aid, fid, aSelectedItems], sAction);
		}
		else
		if (!this.__manageEmptyItems([aid, fid, aSelectedItems],sAction))
			this.__manageMoreItems([aid, fid, aSelectedItems], sAction);
	}
};

_me.__showDialDialog = function(aid, fid, iid) {
	var aPhones = {};

	if (aid && fid && iid) {
	    var aValues = WMItems.list({"aid": aid, "fid": fid, "iid": iid})[aid][fid][iid];

		var aLocations = aValues['LOCATIONS'];

		for (var i in aLocations) {

			if (aLocations[i]['values']['LCTTYPE'] == 'H') {
				var sHomeLocation = aLocations[i];
				var nPhone;

				for (var j in sHomeLocation['PHONES']) {
				    nPhone = sHomeLocation['PHONES'][j]['values']['PHNNUMBER'];
				    if (Is.Defined(nPhone)) aPhones[nPhone] = nPhone;
				}

				break;
			}
		}
	}

	gui._create('dial','frm_dial','','',aPhones);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu_basic2.js <==
_me = obj_hmenu_basic2.prototype;
function obj_hmenu_basic2(){};

_me.__constructor = function() {};

_me._contextFill = function(sType, oFolder, sView, bEnabled)
{
	var aMenu = [];
	this.__oFolder = oFolder;
	
	switch(sType)
	{
		case 'M':
			var folders = (new gw_others).get('DEFAULT_FOLDERS','storage')['VALUES'];
			var sTrashFolder = folders['trash'];
			var sDraftFolder = folders['drafts'];
			var sSentFolder = folders['sent'];
			var sSpamFolder = folders['spam'];
			var sFolderID = oFolder['aid'] + '/' + oFolder['fid'];
			
			if (sFolderID != sDraftFolder && sFolderID != sSentFolder) {
				aMenu.push({"title": 'MAIN_MENU::REPLY_TO_SENDER', 'arg': 'reply_to_sender'});
				aMenu.push({"title": 'MAIN_MENU::REPLY_TO_ALL', 'arg': 'reply_to_all'});
			}
			aMenu.push({"title": 'MAIN_MENU::FORWARD', 'arg': 'forward_from_hmenu'});
            aMenu.push({"title": '-'});
			aMenu.push({"title": 'MAIN_MENU::DELETE', 'arg': 'delete'});
            aMenu.push({"title": '-'});
			aMenu.push({"title": 'MAIN_MENU::PRINT', 'arg': 'print'});
			aMenu.push({"title": 'MAIN_MENU::SEARCH', 'arg': 'search'});
            
			if (sFolderID == sTrashFolder || sFolderID == sSpamFolder)
				aMenu.push({"title": 'MAIN_MENU::EMPTY_FOLDER', 'arg': 'empty_folder'});
			break;

		case 'E':

			aMenu = [
				{"title": 'MAIN_MENU::DAY_VIEW', 'arg': 'day_view'},
				{"title": 'MAIN_MENU::WEEK_VIEW', 'arg':  'week_view'},
				{"title": 'MAIN_MENU::MONTH_VIEW', 'arg': 'month_view'},
				{"title": 'MAIN_MENU::EVENTS_LIST', 'arg': 'list_view'}
			];
			
			if (sView == 'list_view')
				aMenu.push(
                {"title": '-'},
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
				{"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'});
				
			break;

		case 'C':
			aMenu = [];
			if (sPrimaryAccountSIP)
				aMenu.push({"title": 'MAIN_MENU::DIAL', 'arg': 'dial'},{"title": '-'});
				/*{"title": 'MAIN_MENU::CONTACTS_LIST', 'arg': 'phone_list'},
				{"title": 'MAIN_MENU::ADDRESS_CARD', 'arg': 'address_card'},*/

			aMenu.push({"title": 'MAIN_MENU::DELETE', 'arg': 'delete'});

			break;

		case 'T':
			aMenu = [
				/*{"title": 'MAIN_MENU::TASKS_LISTS', 'arg': 'tasks_simple'},
				{"title": 'MAIN_MENU::TASKS_DETAILED', 'arg': 'tasks_detailed'},
				{"title": 'MAIN_MENU::ACTIVE_TASKS', 'arg': 'active_tasks'},*/
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;

		case 'J':
			aMenu = [
				/*{"title": 'MAIN_MENU::JOURNAL_DAY_VIEW', 'arg': 'journal_day_view'},
				{"title": 'MAIN_MENU::JOURNAL_WEEK_VIEW', 'arg': 'journal_week_view'},
				{"title": 'MAIN_MENU::JOURNAL_MONTH_VIEW', 'arg': 'journal_month_view'},
				{"title": 'MAIN_MENU::JOURNAL_LIST', 'arg': 'journal_list'},*/
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}

			];
			break;
			
		case 'N':
			aMenu = [
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;
			
		case 'F':
			aMenu = [
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
                {"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;

		case 'Q':
			aMenu = [
				/*
				{"title": 'MAIN_MENU::WHITE_LISTED', 'arg': 'Whitelist'},
				{"title": 'MAIN_MENU::BLACK_LISTED', 'arg': 'Blacklist'},
				{"title": '-'},
				*/
				{"title": 'MAIN_MENU::DELIVER', 'arg': 'deliver'},
				{"title": 'MAIN_MENU::WHITE_LIST', 'arg': 'whitelist'},
				{"title": 'MAIN_MENU::BLACK_LIST', 'arg': 'blacklist'},
                {"title": '-'},
				{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
				{"title": '-'},
				{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
			];
			break;

		case 'QL':
			if (oFolder['fid'].indexOf('White') >= 0) {
				aMenu = [
				/*
					{"title": 'MAIN_MENU::QUARANTINE', 'arg': 'Quarantine'},
					{"title": 'MAIN_MENU::BLACK_LISTED', 'arg': 'Blacklist'},
					{"title": '-'},
				*/
					{"title": 'MAIN_MENU::BLACK_LIST', 'arg': 'blacklist'},
                    {"title": '-'},
					{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
	                {"title": '-'},
					{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
				];
			} else {
				aMenu = [
				/*
					{"title": 'MAIN_MENU::QUARANTINE', 'arg': 'Quarantine'},
					{"title": 'MAIN_MENU::WHITE_LISTED', 'arg': 'Whitelist'},
					{"title": '-'},
				*/
					{"title": 'MAIN_MENU::WHITE_LIST', 'arg': 'whitelist'},
                    {"title": '-'},
					{"title": 'MAIN_MENU::DELETE', 'arg': 'delete'},
	                {"title": '-'},
					{"title": 'MAIN_MENU::SEARCH', 'arg': 'search'}
				];
			}
			break;
	}

	this._fill(aMenu,'dynamic');
};

_me.__manageEmptyItems = function(id,sAction) {

	switch (sAction) {

		case 'dial':
            if (id[2]) return false;
			this.__showDialDialog();
			return true;

		case 'day_view':
		case 'week_view':
		case 'month_view':
		case 'list_view':
			gui.frm_main._selectView(this.__oFolder, sAction, true);
			return true;
		case 'empty_folder':
			gui._create('frm_confirm', 'frm_confirm', '', '',[WMFolders, '__emptyFolder',
				[this.__oFolder['aid'], this.__oFolder['fid']]],
				'CONFIRMATION::EMPTY_FOLDER_CONFIRMATION', 'CONFIRMATION::EMPTY_FOLDER'
			);
			return true;

		case 'search':
			//HIDE
			if (gui.frm_main.main && gui.frm_main.main.search_item){
                gui.frm_main.main._hidesearch();

				dataSet.remove('datagrid_views',[this.__oFolder['aid'],this.__oFolder['fid'],'search']);
			}
			//SHOW
			else{
				var sFolType = dataSet.get("folders",[this.__oFolder['aid'],this.__oFolder['fid'],'TYPE']);
				gui.frm_main.main._showsearch(sFolType,this.__oFolder['aid']+'/'+this.__oFolder['fid'],true);
				
				dataSet.add('datagrid_views',[this.__oFolder['aid'],this.__oFolder['fid'],'search'],'1');
    	    }
		    return true;
	}
	
	return false;
};

_me.__manageOneItem = function(id, sAction) {
	switch (sAction) {
		case 'reply_to_sender': OldMessage.reply(id, false); return true;
		case 'reply_to_all': OldMessage.reply(id, true); return true;
		case 'forward_from_hmenu': OldMessage.forward(id); return true;
		case 'dial':
			if (count(gui.frm_main.main.list._value()) == 1)
				this.__showDialDialog(id[0], id[1], id[2]);
			else
				this.__showDialDialog();

			return true;
	}
	
	return false;
};

_me.__manageMoreItems = function(ids, sAction) {
	switch (sAction) {
		case 'delete': Item.remove(ids); break;
		case 'deliver': OldMessage.deliver(ids); break;
		case 'whitelist': OldMessage.whitelist(ids); break;
		case 'blacklist': OldMessage.blacklist(ids); break;
	}
};

_me._onclick = function(e, elm, id, sAction)
{
	if (!gui.frm_main.main.list)
		this.__manageEmptyItems([aid, fid],sAction);
	else {

		switch(sAction){
		case 'print':
			if (gui.frm_main.main && gui.frm_main.main.mailview)
                gui.frm_main.main.mailview._print();
			return;
		case 'Whitelist':
		case 'Blacklist':
//		case 'Quarantine':
			gui.frm_main.folders._setActive(this.__oFolder['aid']+'/SPAM_QUEUE/'+sAction);
			gui.frm_main.folders._handleNode({aid:this.__oFolder['aid'],fid:'SPAM_QUEUE/'+sAction,ftype:'QL',candelete:false,canrename:false,disabled:false});
		    return;
		}

		var aSelectedItems = gui.frm_main.main.list._value();
		var aid = this.__oFolder['aid'];
		var fid = this.__oFolder['fid'];

		if (count(aSelectedItems) == 0) {
			this.__manageEmptyItems([aid, fid],sAction);
		}
		else
		if (count(aSelectedItems) == 1) {
			if (!this.__manageEmptyItems([aid, fid, aSelectedItems],sAction))
				if (!this.__manageOneItem([aid, fid, aSelectedItems[0]], sAction))
					this.__manageMoreItems([aid, fid, aSelectedItems], sAction);
		}
		else
		if (!this.__manageEmptyItems([aid, fid, aSelectedItems],sAction))
			this.__manageMoreItems([aid, fid, aSelectedItems], sAction);
	}
};

_me.__showDialDialog = function(aid, fid, iid) {
	var aPhones = {};

	if (aid && fid && iid) {
	    var aValues = WMItems.list({"aid": aid, "fid": fid, "iid": iid})[aid][fid][iid];

		var aLocations = aValues['LOCATIONS'];

		for (var i in aLocations) {

			if (aLocations[i]['values']['LCTTYPE'] == 'H') {
				var sHomeLocation = aLocations[i];
				var nPhone;

				for (var j in sHomeLocation['PHONES']) {
				    nPhone = sHomeLocation['PHONES'][j]['values']['PHNNUMBER'];
				    if (Is.Defined(nPhone)) aPhones[nPhone] = nPhone;
				}

				break;
			}
		}
	}

	gui._create('dial','frm_dial','','',aPhones);
};
